==> v0.01.zip: hugo/content/en/Home.md <==
---
title: "Welcome to the website of the Linux User Group Frankfurt"
date: 2021-02-04T10:04:53+01:00
draft: false
---
[![German](/ger.png)](/)

## Right now

-----

:warning: Due to the current situation with regard to the administrative directions regarding the constraints of social interaction unfortunately we are forced to move to virtual meetings instead of physical interaction (talks and Stammtisch) until further notice. As usual, details are posted on our mailing list.

Once the situation has changed, we will publish a update on this location.

-----

Please note: As talk Tuesdays may be subject to change on short notice, please check the talks page for any last-minute changes. (Regular meetings on Mondays take place at the Sandelmühle, talk Tuesdays at Saalbau Gallus. Modifications are announced here.)

{{< dat en >}}

-----

## Who we are

Our group was formed in 1998. The hard core consists of approximately 15 users who are from the Rhine Main area. The number of users on our mailing list is by far bigger though. Similar to other Linux User Groups (LUGs) the focus of our activities is on the free and open source Linux operating system. The LUG Frankfurt does not stop here though but regards itself as a local special interest group for topics around Free and Open Source Software (FOSS) in general.

Members are recruited from all walks of life, ranging from professional Linux system administrators and developers to long-standing enthusiasts to absolute beginners. We do not focus on a partiular distribution but welcome them all (an overview of distributions can be found on our [distribution list](/de/Distriliste)). Although we are a registered association, membership is not mandatory but optional when you want participate in our activities. We focus on the sharing of knowledge and experience and not strict rules; other Unix-like operating systems and MacOS users are more than welcome.

## Meetups

We regularly meet twice a month.

Every second Monday we host a [regulars' table](/en/Meetup) (we are a German community after all :-) ). We meet at around 7 pm at the [Sandelmühle](http://www.sandelmuehle.de/restaurant/restaurant-frankfurt/), An der Sandelmühle 35, 60439 Frankfurt. You are more than welcome to bring your laptop; power and Wifi are provided by the location. We aim to help with all Linux issues.

Every fourth Tuesday we meet at room # 4 at the [Saalbau Gallus](https://www.saalbau.com/raumangebot/detail/?SAALBAU-Gallus&objekt=52) Frankenallee 111, 60326 Frankfurt, for the [monthly talk](/de/Vortraege). These talks also start around 7 pm. After the talk we normally gather in a nearby restaurant called ~~Hufnagel (Hufnagelstraße 12a, 60326 Frankfurt a.M.)~~ (needs to be checked). These talks are normally in German but most of the time we do have English speaking members around for a chat.

## Mailing list

Between events we communicate via our [mailing list](/de/Mailingliste), which is open to all interested parties.

## Talks

The focus of the Tuesday meetups is a presentation on a FOSS topic. These talks are open to all interested parties who would like to give a presentation on a Linux / FOSS subject. Suggestions for topics can be found here. These talks normally start around 7 pm.

The schedule of these talks can be found [here](/de/Vortraege).

## The Linux Presentation Day

![LPD](/LPD.png)

Since 2015 we have been a part of the international Linux Presentation Day; since 2016 in media association with the Westdeutscher Rundfunk (WDR) as part of the MausTürÖffnerTag.

The Linux Presentation Day is an event where primarily German-speaking LUGs present Linux and FOSS in general to a greater audience which does not know Linux very well or not at all. The aim is a first touch and introduction to this operating system and its applications.

The MausTürÖffnerTag is an opportunity to look behind doors of administrations, companies and associations which are normally closed to the public. In addition, it is an ideal opportunity to introduct children at school age to Linux and FOSS in general.

The slides of the first LPD in Frankfurt and the corresponding live recording can be found [here](/de/LPD).

-----

## Disclosure of automated data storage and processing according to the General Data Protection Regulation (GDPR)

### Provision of our statutory and business services

We process the data of our members, supporters, prospects, customers or other persons in accordance with Art. 6 para. 1 lit. b. GDPR, if we offer them contractual services or in the context of an existing business relationship, e.g. members, or are themselves recipients of benefits and benefits. Incidentally, we process the data of affected persons in accordance with. Art. 6 para. 1 lit. f. GDPR based on our legitimate interests, e.g. when it comes to administrative tasks or public relations.

The data processed, the nature, scope and purpose and necessity of their processing are determined by the underlying contractual relationship. This includes in principle inventory and master data of the persons (e.g., name, address, etc.) as well as the contact data (e.g., e-mail address, telephone, etc.).

We delete data that is no longer required to serve our statutory and business purposes. This is determined according to the respective tasks and contractual relationships. In the case of business processing, we retain the data for as long as they may be relevant to the transaction, as well as with regard to any warranty or liability obligations. The necessity of keeping the data is checked every three years; otherwise the statutory storage obligations apply.

### Hosting and e-mailing

The hosting services we use are designed to provide the following services: infrastructure and platform services, computing capacity, storage and database services, e-mailing, security and technical maintenance services we use to operate this online service.

Here we, or our hosting provider, process inventory data, contact data, content data, contract data, usage data, meta and communication data of customers, interested parties and visitors to this online offer on the basis of our legitimate interests in an efficient and secure provision of this online offer acc. Art. 6 para. 1 lit. f GDPR i.V.m. Art. 28 GDPR (conclusion of contract processing contract).

### Registration

Users can create a user account. As part of the registration, the required mandatory information is communicated to the users and based on Art. 6 para. 1 lit. b GDPR processed for purposes of providing the user account. The processed data include in particular the login information (name, password and an e-mail address). The data entered during registration will be used for the purpose of using the user account and its purpose.

Users may have access to information relevant to their user account, e.g. technical changes, be informed by e-mail. If users have terminated their user account, their data will be deleted with respect to the user account, subject to a statutory retention requirement. It is the responsibility of the users to secure their data upon termination before the end of the contract. We are entitled to irretrievably delete all user data stored during the term of the contract.

As part of the use of our registration and registration functions as well as the use of the user account, the IP address and the time of the respective user action will be saved. The storage is based on our legitimate interests, as well as the user's protection against misuse and other unauthorized use. A transfer of these data to third parties does not take place, unless it is necessary for the prosecution of our claims or there is a legal obligation in accordance with. Art. 6 para. 1 lit. c GDPR.

==> v0.03.zip: hugo/content/en/Home.md <==
---
title: "Welcome to the website of the Linux User Group Frankfurt"
date: 2021-02-04T10:04:53+01:00
draft: false
---
[![German](/ger.png#floatright)](/)

## Right now

-----

:warning: Due to the current situation with regard to the administrative directions regarding the constraints of social interaction unfortunately we are forced to move to virtual meetings instead of physical interaction (talks and Stammtisch) until further notice. As usual, details are posted on our mailing list.

Once the situation has changed, we will publish a update on this location.

-----

Please note: As talk Tuesdays may be subject to change on short notice, please check the talks page for any last-minute changes. (Regular meetings on Mondays take place at the Sandelmühle, talk Tuesdays at Saalbau Gallus. Modifications are announced here.)

{{< dat en >}}

-----

## Who we are

Our group was formed in 1998. The hard core consists of approximately 15 users who are from the Rhine Main area. The number of users on our mailing list is by far bigger though. Similar to other Linux User Groups (LUGs) the focus of our activities is on the free and open source Linux operating system. The LUG Frankfurt does not stop here though but regards itself as a local special interest group for topics around Free and Open Source Software (FOSS) in general.

Members are recruited from all walks of life, ranging from professional Linux system administrators and developers to long-standing enthusiasts to absolute beginners. We do not focus on a partiular distribution but welcome them all (an overview of distributions can be found on our [distribution list](/de/Distriliste)). Although we are a registered association, membership is not mandatory but optional when you want participate in our activities. We focus on the sharing of knowledge and experience and not strict rules; other Unix-like operating systems and MacOS users are more than welcome.

## Meetups

We regularly meet twice a month.

Every second Monday we host a [regulars' table](/en/Meetup) (we are a German community after all :-) ). We meet at around 7 pm at the {{< tabref href="http://www.sandelmuehle.de/restaurant/restaurant-frankfurt" title="Sandelmühle" >}}, An der Sandelmühle 35, 60439 Frankfurt. You are more than welcome to bring your laptop; power and Wifi are provided by the location. We aim to help with all Linux issues.

Every fourth Tuesday we meet at room # 4 at the {{< tabref
href="https://www.saalbau.com/raumangebot/detail/?SAALBAU-Gallus&objekt=52" title="Sallbau Gallus" >}} Frankenallee 111, 60326 Frankfurt, for the [monthly talk](/de/Vortraege). These talks also start around 7 pm. After the talk we normally gather in a nearby restaurant called ~~Hufnagel (Hufnagelstraße 12a, 60326 Frankfurt a.M.)~~ (needs to be checked). These talks are normally in German but most of the time we do have English speaking members around for a chat.

## Mailing list

Between events we communicate via our [mailing list](/de/Mailingliste), which is open to all interested parties.

## Talks

The focus of the Tuesday meetups is a presentation on a FOSS topic. These talks are open to all interested parties who would like to give a presentation on a Linux / FOSS subject. Suggestions for topics can be found here. These talks normally start around 7 pm.

The schedule of these talks can be found [here](/de/Vortraege).

## The Linux Presentation Day

![LPD](/LPD.png)

Since 2015 we have been a part of the international Linux Presentation Day; since 2016 in media association with the Westdeutscher Rundfunk (WDR) as part of the MausTürÖffnerTag.

The Linux Presentation Day is an event where primarily German-speaking LUGs present Linux and FOSS in general to a greater audience which does not know Linux very well or not at all. The aim is a first touch and introduction to this operating system and its applications.

The MausTürÖffnerTag is an opportunity to look behind doors of administrations, companies and associations which are normally closed to the public. In addition, it is an ideal opportunity to introduct children at school age to Linux and FOSS in general.

The slides of the first LPD in Frankfurt and the corresponding live recording can be found [here](/de/LPD).

-----

## Disclosure of automated data storage and processing according to the General Data Protection Regulation (GDPR)

### Provision of our statutory and business services

We process the data of our members, supporters, prospects, customers or other persons in accordance with Art. 6 para. 1 lit. b. GDPR, if we offer them contractual services or in the context of an existing business relationship, e.g. members, or are themselves recipients of benefits and benefits. Incidentally, we process the data of affected persons in accordance with. Art. 6 para. 1 lit. f. GDPR based on our legitimate interests, e.g. when it comes to administrative tasks or public relations.

The data processed, the nature, scope and purpose and necessity of their processing are determined by the underlying contractual relationship. This includes in principle inventory and master data of the persons (e.g., name, address, etc.) as well as the contact data (e.g., e-mail address, telephone, etc.).

We delete data that is no longer required to serve our statutory and business purposes. This is determined according to the respective tasks and contractual relationships. In the case of business processing, we retain the data for as long as they may be relevant to the transaction, as well as with regard to any warranty or liability obligations. The necessity of keeping the data is checked every three years; otherwise the statutory storage obligations apply.

### Hosting and e-mailing

The hosting services we use are designed to provide the following services: infrastructure and platform services, computing capacity, storage and database services, e-mailing, security and technical maintenance services we use to operate this online service.

Here we, or our hosting provider, process inventory data, contact data, content data, contract data, usage data, meta and communication data of customers, interested parties and visitors to this online offer on the basis of our legitimate interests in an efficient and secure provision of this online offer acc. Art. 6 para. 1 lit. f GDPR i.V.m. Art. 28 GDPR (conclusion of contract processing contract).

### Registration

Users can create a user account. As part of the registration, the required mandatory information is communicated to the users and based on Art. 6 para. 1 lit. b GDPR processed for purposes of providing the user account. The processed data include in particular the login information (name, password and an e-mail address). The data entered during registration will be used for the purpose of using the user account and its purpose.

Users may have access to information relevant to their user account, e.g. technical changes, be informed by e-mail. If users have terminated their user account, their data will be deleted with respect to the user account, subject to a statutory retention requirement. It is the responsibility of the users to secure their data upon termination before the end of the contract. We are entitled to irretrievably delete all user data stored during the term of the contract.

As part of the use of our registration and registration functions as well as the use of the user account, the IP address and the time of the respective user action will be saved. The storage is based on our legitimate interests, as well as the user's protection against misuse and other unauthorized use. A transfer of these data to third parties does not take place, unless it is necessary for the prosecution of our claims or there is a legal obligation in accordance with. Art. 6 para. 1 lit. c GDPR.
